@@ -1,9 +1,9 @@
 package Dist::Zilla::PluginBundle::SCHWIGON;
-BEGIN {
-  $Dist::Zilla::PluginBundle::SCHWIGON::AUTHORITY = 'cpan:SCHWIGON';
-}
+# git description: v0.018-2-gb3bc1a3
+
+our $AUTHORITY = 'cpan:SCHWIGON';
 # ABSTRACT: Build your distributions like SCHWIGON does
-$Dist::Zilla::PluginBundle::SCHWIGON::VERSION = '0.018';
+$Dist::Zilla::PluginBundle::SCHWIGON::VERSION = '0.019';
 # (well actually like FLORA - as it is shamelessly stolen)
 
 use 5.008;
